# FeatureTableJoinedFeatureServiceResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 
**name** | **str** |  | 
**description** | **str** |  | [optional] 
**synced_at** | **datetime** |  | [optional] 
**organization_id** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

